@@ -14,26 +14,28 @@ class QuickWidget : public QeMaemo5DynamicHomescreenWidget
     Q_OBJECT
 
 private:
-    void initView(const QString& fileName, const QSize& size=QSize());
+    void initView(const QString& fileName, const QSize& size=QSize(),
+		  bool rotate=false);
     QSize size_;
     QDeclarativeView* view_;
     QuickWidgetWrapper* wrapper_;
+    bool landscape_;
 
 protected:
 //    void showSettingsDialog();
     bool restoreWidgetState();
     void errorWidget();
-    bool x11Event(XEvent *event);
-    void paintEvent(QPaintEvent *event);
 
 public slots:
-  void resizer(QSize size);
+  void resizer(const QSize& size);
+  void rotateScreen(const QString& orientation);
 
 public:
-    static QuickWidget *createAndShowNew(const QString& fileName, const QSize& size=QSize());
+    static QuickWidget *createAndShowNew(const QString& fileName, 
+					 const QSize& size=QSize(),
+					 bool rotate=false);
 
     explicit QuickWidget(QWidget *parent = 0);
-    Q_INVOKABLE bool onHomescreen() { return isVisibleOnCurrentHomescreen(); }
     ~QuickWidget();
 
 };
@@ -49,22 +51,20 @@ public:
     QuickWidgetWrapper(QuickWidget *owner) : m_owner(owner) {;}
     Q_PROPERTY(bool isActiveWindow READ onHomeScreen NOTIFY onHomeScreenChanged);
 
-    bool onHomeScreen() const { return homeScreen; }
+    bool onHomeScreen() const { return m_homeScreen; }
 
+public slots:
     void setOnHomeScreen(bool active)
     {
-        if (active == homeScreen)
+        if (active == m_homeScreen)
             return;
-        homeScreen = active;
+        m_homeScreen = active;
         emit onHomeScreenChanged();
     }
 
-
 private:
     QuickWidget *m_owner;
-    bool homeScreen;
-
-
+    bool m_homeScreen;
 };
 
 #endif // QuickWidget_HPP
