@@ -19,6 +19,7 @@ QuickWidgetSettings::~QuickWidgetSettings()
 void QuickWidgetSettings::accept() {
     QFile f(ui->fileEdit->text());
     QSize size;
+    bool rotate = ui->autoRotateCheckBox->isChecked();
     if (ui->sizingCheckBox->isChecked()) {
         bool wok, hok;
         int width = ui->widthEdit->text().toInt(&wok);
@@ -30,7 +31,7 @@ void QuickWidgetSettings::accept() {
     }
     if (f.exists())
     {
-        QuickWidget::createAndShowNew(ui->fileEdit->text(), size);
+      QuickWidget::createAndShowNew(ui->fileEdit->text(), size, rotate);
     }
 
     QDialog::accept();
